@@ -41,8 +41,6 @@
 
 #define KIRIGAMI2_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 #if defined(KIRIGAMI2_NO_DEPRECATED)
 #  undef KIRIGAMI2_DEPRECATED
 #  define KIRIGAMI2_DEPRECATED_EXPORT KIRIGAMI2_EXPORT
@@ -63,7 +61,7 @@
 #define KIRIGAMI2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIRIGAMI2_NO_DEPRECATED
-#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KIRIGAMI2_NO_DEPRECATED_WARNINGS
 #  define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +71,7 @@
 #  ifdef KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -82,7 +80,7 @@
 #endif
 
 #ifdef KIRIGAMI2_DEPRECATED
-#  define KIRIGAMI2_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KIRIGAMI2_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KIRIGAMI2_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
